@@ -1,7 +1,4 @@
-"""Requirements specific to SQLAlchemy's own unit tests.
-
-
-"""
+"""Requirements specific to SQLAlchemy's own unit tests."""
 
 from sqlalchemy import exc
 from sqlalchemy.sql import sqltypes
@@ -162,6 +159,10 @@ class DefaultRequirements(SuiteRequirements):
     def fk_constraint_option_reflection_onupdate_restrict(self):
         return only_on(["postgresql", "sqlite", self._mysql_80])
 
+    @property
+    def temp_table_comment_reflection(self):
+        return only_on(["postgresql", "mysql", "mariadb", "oracle"])
+
     @property
     def comment_reflection(self):
         return only_on(["postgresql", "mysql", "mariadb", "oracle", "mssql"])
@@ -212,6 +213,19 @@ class DefaultRequirements(SuiteRequirements):
             ]
         )
 
+    @property
+    def server_defaults(self):
+        """Target backend supports server side defaults for columns"""
+
+        return exclusions.open()
+
+    @property
+    def expression_server_defaults(self):
+        return skip_if(
+            lambda config: against(config, "mysql", "mariadb")
+            and not self._mysql_expression_defaults(config)
+        )
+
     @property
     def qmark_paramstyle(self):
         return only_on(["sqlite", "+pyodbc"])
@@ -726,6 +740,24 @@ class DefaultRequirements(SuiteRequirements):
             ]
         )
 
+    @property
+    def ctes_with_values(self):
+        return only_on(
+            [
+                lambda config: against(config, "mysql")
+                and (
+                    (
+                        config.db.dialect._is_mariadb
+                        and config.db.dialect._mariadb_normalized_version_info
+                        >= (10, 2)
+                    )
+                ),
+                "mariadb>10.2",
+                "postgresql",
+                "sqlite>=3.8.3",
+            ]
+        )
+
     @property
     def ctes_with_update_delete(self):
         """target database supports CTES that ride on top of a normal UPDATE
@@ -983,6 +1015,10 @@ class DefaultRequirements(SuiteRequirements):
         """
         return exclusions.open()
 
+    @property
+    def nvarchar_types(self):
+        return only_on(["mssql", "oracle", "sqlite", "mysql", "mariadb"])
+
     @property
     def unicode_data_no_special_types(self):
         """Target database/dialect can receive / deliver / compare data with
@@ -1012,7 +1048,12 @@ class DefaultRequirements(SuiteRequirements):
 
     @property
     def arraysize(self):
-        return skip_if("+pymssql", "DBAPI is missing this attribute")
+        return skip_if(
+            [
+                no_support("+pymssql", "DBAPI is missing this attribute"),
+                no_support("+mysqlconnector", "DBAPI ignores this attribute"),
+            ]
+        )
 
     @property
     def emulated_lastrowid(self):
@@ -1813,6 +1854,15 @@ class DefaultRequirements(SuiteRequirements):
         # 2. they dont enforce check constraints
         return not self._mysql_check_constraints_exist(config)
 
+    def _mysql_expression_defaults(self, config):
+        return (against(config, ["mysql", "mariadb"])) and (
+            config.db.dialect._support_default_function
+        )
+
+    @property
+    def mysql_expression_defaults(self):
+        return only_if(self._mysql_expression_defaults)
+
     def _mysql_not_mariadb_102(self, config):
         return (against(config, ["mysql", "mariadb"])) and (
             not config.db.dialect._is_mariadb
